<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:tdm="http://www.quest.com/toad-data-modeler">
	<tdm:description>Report of Tablespaces. This report gives you an overview of modeled tablespaces and objects that belong to particular tablespace.</tdm:description>
	<tdm:caption>Tablespaces (HTML)</tdm:caption>
	<tdm:default-filename>tablespaces</tdm:default-filename>
	<tdm:default-suffix>html</tdm:default-suffix>
	<tdm:db-platforms>
		<tdm:db-platform>OR9</tdm:db-platform>
		<tdm:db-platform>OR10</tdm:db-platform>
		<tdm:db-platform>OR11R1</tdm:db-platform>
		<tdm:db-platform>OR11R2</tdm:db-platform>
	</tdm:db-platforms>

	<xsl:output version="4.0" method="html" indent="yes" omit-xml-declaration="yes" encoding="UTF-8" doctype-public="-//W3C//DTD HTML 4.0 Transitional//EN" doctype-system="http://www.w3.org/TR/html4/loose.dtd"/>
	<xsl:param name="GenerateModelInfo" select="True" />
	<xsl:decimal-format name="format1" grouping-separator=" " decimal-separator=","/>
	<xsl:template match="/">
		<html>
			<head>
				<title/>
				<style type="text/css">
					<xsl:comment>

						/* --------------------------------------- */
						/* -------------- LEFT FRAME ------------- */
						/* --------------------------------------- */
						#navLeft {
						position: fixed;
						top: 10px;
						left: 10px;
						bottom: 10px;
						text-align: center;
						z-index: 3;
						width: 200px;
						background: #ffffff;
						z-index: 5;
						background: #C8DEF7;
						padding: 1px;
						border: 1px solid #6FA9EA;
						float: left;
						overflow: auto;
						}

						#bookmark {
						font-family : Verdana, Geneva, Arial, Helvetica, sans-serif;
						font-size : 8pt;
						font-weight : normal;
						text-align : left;
						width : 100%;
						visibility : visible;
						margin: 0px;
						padding: 0px;
						}

						#bookmarkEnd {
						display: none;
						}

						#bookmark ul {
						list-style-type:none;
						cursor: pointer;
						border-top: 1px solid white;
						border-left: 1px solid white;
						border-right: 1px solid white;
						margin: 0px;
						padding: 0px;
						width: 100%;
						}

						#bookmark ul li {
						margin: 0px;
						list-style-type:none;
						cursor: pointer;
						color: black;
						display: block;
						border-bottom: 1px solid white;
						}

						#bookmark ul li a {
						display: block;
						visibility : visible;
						cursor: pointer;
						display : block;
						padding: 4px 4px 4px 10px;
						line-height: 12px;
						color: #000;
						}

						#bookmark ul li a:link, #bookmark ul li a:visited {
						list-style-type:none;
						color: #000;
						font-family : Verdana, Geneva, Arial, Helvetica, sans-serif;
						font-size : 8pt;
						font-weight : normal;
						text-align : left;
						text-decoration : none;
						display: block;
						visibility : visible;
						cursor: pointer;
						}

						#bookmark ul li a:hover, #bookmark ul li:hover
						{
						font-weight: bold;
						color: white;
						background: #6FA9EA;
						display: block;
						}

						#bookmark ul li a:active {
						}

						.bookmarkHeader {
						font-weight: bold;
						color: black;
						border-bottom: 1px solid #C8DEF7;
						cursor: text;
						}

						#bookmark .spacer, #bookmark .spacer:hover{
						height: 10px;
						line-height: 10px;
						padding-top: 10px;
						background: #C8DEF7;
						cursor: text;
						}

						.normal{
						font-weight:  normal;
						}

						h1 {
						color: #000;
						font-family : Verdana, Geneva, Arial, Helvetica, sans-serif;
						margin: 15px 0px 5px 0px;
						padding: 0px;
						}

						h2 {
						color: #B20000;
						font-family : Verdana, Geneva, Arial, Helvetica, sans-serif;
						font-size : 10pt;
						font-weight : bold;
						margin: 20px 0px 10px 0px;
						padding: 10px 0px 10px 0px;

						visibility : visible;
						border-top: 1px solid #B20000;
						width: 770px;
						}


						/* --------------------------------------- */
						/* -------------- CONTENT ------------- */
						/* --------------------------------------- */

						.container{
						margin: 0px;
						padding: 0px;
						position: absolute;
						top: 0px;
						z-index: 0;
						padding-top: 10px;
						width: 100%;
						}

						#content{
						margin: 0px;
						margin-left: 230px;
						margin-right: 10px;
						padding: 0px 20px 20px 20px;
						}


						.tabFormat {
						border:1px solid #6FA9EA;;
						}

						.tabHead {
						color: #000;
						font-family : Verdana, Geneva, Arial, Helvetica, sans-serif;
						font-size : 8pt;
						font-weight : normal;
						text-align : left;
						border: 0pt solid #000000;
						padding-bottom : 3px;
						padding-left : 10px;
						padding-right : 2px;
						padding-top : 3px;
						background:  #C8DEF7;
						visibility : visible;
						}

						.tabData {
						color: #333333;
						font-family : Verdana, Geneva, Arial, Helvetica, sans-serif;
						font-size : 8pt;
						font-weight : normal;
						text-align : left;
						border: 0pt solid #000000;
						padding-bottom : 3px;
						padding-left : 10px;
						padding-right : 2px;
						padding-top : 3px;
						background :#F8F8F8;
						visibility : visible;
						}

						h1 { font-family:Arial;
						font-size:larger;
						font-style:normal;
						margin:0px;
						margin-bottom:2px;
						margin-top:10px;
						}
						ul { margin:0px;
						padding:0px;
						}
						li { margin:0px;
						padding:0px;
						list-style-type: none;
						}
					</xsl:comment>
				</style>
			</head>
			<body>
				<div id="navLeft">
					<div id="bookmark">
						<ul>
							<xsl:for-each select="//Model/Tablespaces/Tablespace">
								<xsl:for-each select="Name">
									<li>
										<a>
											<xsl:choose>
												<xsl:when test="substring(string(concat(&apos;#tablespace&apos;,../Id)), 1, 1) = '#'">
													<xsl:attribute name="href">
														<xsl:value-of select="concat(&apos;#tablespace&apos;,../Id)"/>
													</xsl:attribute>
												</xsl:when>
												<xsl:otherwise>
													<xsl:attribute name="href">
														<xsl:if test="substring(string(concat(&apos;#tablespace&apos;,../Id)), 2, 1) = ':'">
															<xsl:text></xsl:text>
														</xsl:if>
														<xsl:value-of select="translate(string(concat(&apos;#tablespace&apos;,../Id)), '&#x5c;', '/')"/>
													</xsl:attribute>
												</xsl:otherwise>
											</xsl:choose>
											<xsl:apply-templates/>
										</a>
									</li>
								</xsl:for-each>
							</xsl:for-each>

						</ul>
					</div>
				</div>
				<div class="container">
					<div id="content">
						<xsl:if test="$GenerateModelInfo='True'">
							<h1>
								<xsl:text>Model information</xsl:text>
							</h1>
							<xsl:call-template name="ModelInfo" />

							<br />
						</xsl:if>
						<h1>

							<xsl:text>Tablespaces</xsl:text>

						</h1>
						<xsl:choose>
							<xsl:when test="count(//Model/Tablespaces/Tablespace) > 0">
								<xsl:for-each select="//Model/Tablespaces/Tablespace">
									<h2>
										<xsl:for-each select="FullName">
											<a>
												<xsl:attribute name="name">
													<xsl:value-of select="concat(&apos;tablespace&apos;,../Id)"/>
												</xsl:attribute>
												<xsl:apply-templates/>
											</a>
										</xsl:for-each>
									</h2>
									<table class="tabFormat" width="100%">
										<tbody>
											<tr>
												<td class="tabHead" width="200px">
													<span>
														<xsl:text>Object</xsl:text>
													</span>
												</td>
												<td class="tabHead">
													<span>
														<xsl:text>Count</xsl:text>
													</span>
												</td>
											</tr>
											<tr class="tabData">
												<td class="tabData" width="200px">
													<span>
														<xsl:text>Entities</xsl:text>
													</span>
												</td>
												<td class="tabData">
													<span>
														<xsl:value-of select="count(  Entities/ReferencedObject )"/>
													</span>
												</td>
											</tr>
											<tr class="tabData">
												<td class="tabData" width="200px">
													<span>
														<xsl:text>Key Constraints</xsl:text>
													</span>
												</td>
												<td class="tabData">
													<span>
														<xsl:value-of select="count(  KeyConstraints/ReferencedObject  )"/>
													</span>
												</td>
											</tr>
											<tr class="tabData">
												<td class="tabData" width="200px">
													<span>
														<xsl:text>Indexes</xsl:text>
													</span>
												</td>
												<td class="tabData">
													<span>
														<xsl:value-of select="count(  Indexes/ReferencedObject  )"/>
													</span>
												</td>
											</tr>
											<tr class="tabData">
												<td class="tabData" width="200px">
													<span>
														<xsl:text>Relations</xsl:text>
													</span>
												</td>
												<td class="tabData">
													<span>
														<xsl:value-of select="count(  Relations/ReferencedObject  )"/>
													</span>
												</td>
											</tr>
											<tr class="tabData">
												<td class="tabData" width="200px">
													<span>
														<xsl:text>Materialized Views</xsl:text>
													</span>
												</td>
												<td class="tabData">
													<span>
														<xsl:value-of select="count(  MaterializedViews/ReferencedObject  )"/>
													</span>
												</td>
											</tr>
										</tbody>
									</table>
									<br />
									<table  class="tabFormat" width="100%">
										<tbody>
											<tr>
												<td class="tabHead" width="200px">
													<span>
														<xsl:text>Entities</xsl:text>
													</span>
												</td>
												<td class="tabData">
													<ul>
														<xsl:for-each select="Entities">
															<xsl:for-each select="ReferencedObject">
																<xsl:for-each select="Name">
																	<li>
																		<xsl:apply-templates/>
																	</li>
																</xsl:for-each>
															</xsl:for-each>
														</xsl:for-each>
													</ul>
												</td>
											</tr>
											<tr>
												<td class="tabHead" width="200px">
													<span>
														<xsl:text>Key Constraints</xsl:text>
													</span>
												</td>
												<td class="tabData">
													<ul>
														<xsl:for-each select="KeyConstraints">
															<xsl:for-each select="ReferencedObject">
																<xsl:for-each select="Name">
																	<li>
																		<xsl:apply-templates/>
																	</li>
																</xsl:for-each>
															</xsl:for-each>
														</xsl:for-each>
													</ul>
												</td>
											</tr>
											<tr>
												<td class="tabHead" width="200px">
													<span>
														<xsl:text>Indexes:</xsl:text>
													</span>
												</td>
												<td class="tabData">
													<ul>
														<xsl:for-each select="Indexes">
															<xsl:for-each select="ReferencedObject">
																<xsl:for-each select="Name">
																	<li>
																		<xsl:apply-templates/>
																	</li>
																</xsl:for-each>
															</xsl:for-each>
														</xsl:for-each>
													</ul>
												</td>
											</tr>
											<tr>
												<td class="tabHead" width="200px">
													<span>
														<xsl:text>Relations:</xsl:text>
													</span>
												</td>
												<td class="tabData">
													<ul>
														<xsl:for-each select="Relations">
															<xsl:for-each select="ReferencedObject">
																<xsl:for-each select="Name">
																	<li>
																		<xsl:apply-templates/>
																	</li>
																</xsl:for-each>
															</xsl:for-each>
														</xsl:for-each>
													</ul>
												</td>
											</tr>
											<tr>
												<td class="tabHead" width="200px">
													<span>
														<xsl:text>Materialized views:</xsl:text>
													</span>
												</td>
												<td class="tabData">
													<ul>
														<xsl:for-each select="MaterializedViews">
															<xsl:for-each select="ReferencedObject">
																<xsl:for-each select="Name">
																	<li>
																		<xsl:apply-templates/>
																	</li>
																</xsl:for-each>
															</xsl:for-each>
														</xsl:for-each>
													</ul>
												</td>
											</tr>
										</tbody>
									</table>
								</xsl:for-each>
							</xsl:when>
							<xsl:otherwise>
								<xsl:text>No Tablespaces found.</xsl:text>
							</xsl:otherwise>
						</xsl:choose>
					</div>
				</div>
			</body>
		</html>
	</xsl:template>
	<xsl:template name="ModelInfo">
		<br/>
		<table class="tabFormat" width="100%">
			<tbody>
				<tr>
					<td class="tabHead">
						<span>
							<xsl:text>Model name:</xsl:text>
						</span>
					</td>
					<td class="tabData">
						<xsl:value-of select="//Model/ModelTitle/ModelName" />

					</td>
				</tr>
				<tr>
					<td class="tabHead">
						<span>
							<xsl:text>Author:</xsl:text>
						</span>
					</td>
					<td class="tabData">
						<xsl:value-of select="//Model/ModelTitle/Author" />
					</td>
				</tr>
				<tr>
					<td class="tabHead">
						<span>
							<xsl:text>Company:</xsl:text>
						</span>
					</td>
					<td class="tabData">
						<xsl:value-of select="//Model/ModelTitle/Company" />
					</td>
				</tr>
				<tr>
					<td class="tabHead">
						<span>
							<xsl:text>Created:</xsl:text>
						</span>
					</td>
					<td class="tabData">
						<span>
							<xsl:value-of select="format-number(number(substring(string(string(//Model/ModelTitle/CreatedDate)), 6, 2)), '00', 'format1')"/>
							<xsl:text>/</xsl:text>
							<xsl:value-of select="format-number(number(substring(string(string(//Model/ModelTitle/CreatedDate)), 9, 2)), '00', 'format1')"/>
							<xsl:text>/</xsl:text>
							<xsl:value-of select="format-number(number(substring(string(string(string(//Model/ModelTitle/CreatedDate))), 1, 4)), '0000', 'format1')"/>
						</span>
					</td>
				</tr>
				<tr>
					<td class="tabHead">
						<span>
							<xsl:text>Description:</xsl:text>
						</span>
					</td>
					<td class="tabData">
						<xsl:value-of select="//Model/ModelTitle/Description" />
					</td>
				</tr>
			</tbody>
		</table>
	</xsl:template>
</xsl:stylesheet>
